==> isw_mobile_sdk-1.0.0-5.6.tar.gz: lib/isw_mobile_sdk.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

enum Environment { PRODUCTION, SANDBOX, TEST }

enum PaymentChannel { CARD, WALLET, QR, USSD, PAYCODE }


class IswSdkConfig {
  final String merchantId;
  final String merchantSecret;
  final String merchantCode;
  final String currencyCode;

  IswSdkConfig(this.merchantId, this.merchantSecret, this.merchantCode,
      this.currencyCode);

  Map<String, String> toMap() {
    return {
      'merchantId': this.merchantId,
      'merchantSecret': this.merchantSecret,
      'merchantCode': this.merchantCode,
      'currencyCode': this.currencyCode
    };
  }
}

class IswPaymentInfo {
  final String customerId;
  final String customerName;
  final String customerEmail;
  final String customerMobile;
  final String reference;
  final int amount;

  IswPaymentInfo(this.customerId, this.customerName, this.customerEmail,
      this.customerMobile, this.reference, this.amount);

  Map<String, String> toMap() {
    return {
      'customerId': this.customerId,
      'customerName': this.customerName,
      'customerEmail': this.customerEmail,
      'customerMobile': this.customerMobile,
      'reference': this.reference,
      'amount': this.amount.toString()
    };
  }
}

class IswPaymentResult {
  final String responseCode;
  final String responseDescription;
  final bool isSuccessful;
  final String transactionReference;
  final int amount;
  final PaymentChannel channel;

  IswPaymentResult(this.responseCode, this.responseDescription,
      this.isSuccessful, this.transactionReference, this.amount, this.channel);

  static IswPaymentResult fromJson(Map<dynamic, dynamic> json) {
    final isSuccessful = json['isSuccessful'].toLowerCase() == 'true';

    final providedChannel = json['channel'];
    var channel;
    if (providedChannel == nameOf(PaymentChannel.CARD)) {
      channel = PaymentChannel.CARD;
    } else if (providedChannel == nameOf(PaymentChannel.WALLET)) {
      channel = PaymentChannel.WALLET;
    } else if (providedChannel == nameOf(PaymentChannel.USSD)) {
      channel = PaymentChannel.USSD;
    } else if (providedChannel == nameOf(PaymentChannel.QR)) {
      channel = PaymentChannel.QR;
    } else {
      channel = PaymentChannel.PAYCODE;
    }

    return new IswPaymentResult(
        json['responseCode'],
        json['responseDescription'],
        isSuccessful,
        json['transactionReference'],
        int.parse(json['amount']),
        channel);
  }

  static String nameOf(PaymentChannel channel) {
    final name = channel.toString();
    return "${name.substring(name.indexOf('.') + 1)}";
  }
}

class Optional<T> {
  final T value;
  final bool hasValue;

  Optional(this.value, this.hasValue);
}

class IswMobileSdk {
  static const MethodChannel _channel =
      const MethodChannel('com.interswitchng.isw_mobile_sdk');

  static Future<void> initialize(IswSdkConfig config,
      [Environment env = Environment.TEST]) async {
    // Errors occurring on the platform side cause invokeMethod to throw
    // PlatformExceptions.
    try {
      return _channel.invokeMethod('initialize', {'config': config.toMap(), 'env': nameOf(env)});
    } on PlatformException {
      throw 'Unable to configure sdk';
    }
  }

  static Future<Optional<IswPaymentResult>> pay(IswPaymentInfo info) async {
    try {
      final result =
          await _channel.invokeMethod('pay', {'paymentInfo': info.toMap()});
      if (result == null) {
        return Optional(null, false);
      } else {
        return Optional(IswPaymentResult.fromJson(result), true);
      }
    } on PlatformException {
      throw 'Unable to complete payment';
    }
  }

  static String nameOf(Environment env) {
    final name = env.toString();
    return "${name.substring(name.indexOf('.') + 1)}";
  }
}

==> isw_mobile_sdk-1.0.6.tar.gz: lib/isw_mobile_sdk.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

enum Environment { PRODUCTION, SANDBOX, TEST }

enum PaymentChannel { CARD, WALLET, QR, USSD, PAYCODE }


class IswSdkConfig {
  final String merchantId;
  final String merchantSecrete;
  final String merchantCode;
  final String currencyCode;

  IswSdkConfig(this.merchantId, this.merchantSecrete, this.merchantCode,
      this.currencyCode);

  Map<String, String> toMap() {
    return {
      'merchantId': this.merchantId,
      'merchantSecrete': this.merchantSecrete,
      'merchantCode': this.merchantCode,
      'currencyCode': this.currencyCode
    };
  }
}

class IswPaymentInfo {
  final String customerId;
  final String customerName;
  final String customerEmail;
  final String customerMobile;
  final String reference;
  final int amount;

  IswPaymentInfo(this.customerId, this.customerName, this.customerEmail,
      this.customerMobile, this.reference, this.amount);

  Map<String, String> toMap() {
    return {
      'customerId': this.customerId,
      'customerName': this.customerName,
      'customerEmail': this.customerEmail,
      'customerMobile': this.customerMobile,
      'reference': this.reference,
      'amount': this.amount.toString()
    };
  }
}

class IswPaymentResult {
  final String responseCode;
  final String responseDescription;
  final bool isSuccessful;
  final String transactionReference;
  final int amount;
  final PaymentChannel channel;

  IswPaymentResult(this.responseCode, this.responseDescription,
      this.isSuccessful, this.transactionReference, this.amount, this.channel);

  static IswPaymentResult fromJson(Map<dynamic, dynamic> json) {
    final isSuccessful = json['isSuccessful'].toLowerCase() == 'true';

    final providedChannel = json['channel'];
    var channel;
    if (providedChannel == nameOf(PaymentChannel.CARD)) {
      channel = PaymentChannel.CARD;
    } else if (providedChannel == nameOf(PaymentChannel.WALLET)) {
      channel = PaymentChannel.WALLET;
    } else if (providedChannel == nameOf(PaymentChannel.USSD)) {
      channel = PaymentChannel.USSD;
    } else if (providedChannel == nameOf(PaymentChannel.QR)) {
      channel = PaymentChannel.QR;
    } else {
      channel = PaymentChannel.PAYCODE;
    }

    return new IswPaymentResult(
        json['responseCode'],
        json['responseDescription'],
        isSuccessful,
        json['transactionReference'],
        int.parse(json['amount']),
        channel);
  }

  static String nameOf(PaymentChannel channel) {
    final name = channel.toString();
    return "${name.substring(name.indexOf('.') + 1)}";
  }
}

class Optional<T> {
  final T value;
  final bool hasValue;

  Optional(this.value, this.hasValue);
}

class IswMobileSdk {
  static const MethodChannel _channel =
      const MethodChannel('com.interswitchng.isw_mobile_sdk');

  static Future<void> initialize(IswSdkConfig config,
      [Environment env = Environment.TEST]) async {
    // Errors occurring on the platform side cause invokeMethod to throw
    // PlatformExceptions.
    try {
      return _channel.invokeMethod('initialize', {'config': config.toMap(), 'env': nameOf(env)});
    } on PlatformException {
      throw 'Unable to configure sdk';
    }
  }

  static Future<Optional<IswPaymentResult>> pay(IswPaymentInfo info) async {
    try {
      final result =
          await _channel.invokeMethod('pay', {'paymentInfo': info.toMap()});
      if (result == null) {
        return Optional(result, false);
      } else {
        return Optional(IswPaymentResult.fromJson(result), true);
      }
    } on PlatformException {
      throw 'Unable to complete payment';
    }
  }

  static String nameOf(Environment env) {
    final name = env.toString();
    return "${name.substring(name.indexOf('.') + 1)}";
  }
}
